@@ -23,11 +23,14 @@ from bittrade_cryptodotcom_websocket import (
     subscribe_order_book,
     subscribe_open_orders,
 )
+from elm_framework_helpers.ccxt.models.orderbook import Orderbook
 from bittrade_cryptodotcom_websocket.models import (
     UserBalance,
     CryptodotcomRequestMessage,
 )
 
+from typing import NamedTuple
+
 from bittrade_cryptodotcom_websocket.rest import (
     get_user_balance_factory,
     create_order_factory,
@@ -41,10 +44,15 @@ from ccxt import cryptocom
 logger = getLogger(__name__)
 
 
+class BookConfig(NamedTuple):
+    pair: str
+    depth: int
+
+
 @dataclass
 class CryptodotcomContext:
     all_subscriptions: CompositeDisposable
-    books: dict[str, Observable[list[tuple[str, str]]]]
+    books: dict[str, Observable[Orderbook]]
     cancel_all: Callable[[str, Literal["trigger", "limit", "all"]], Observable[bool]]
     cancel_order: Callable[[str, bool | None, bool | None], Observable[bool]]
     close_position: Callable[
@@ -74,9 +82,9 @@ def cryptodotcom_sockets(
         [Observable[CryptodotcomResponseMessage]],
         Callable[[EnhancedWebsocket], Observable[EnhancedWebsocket]],
     ],
-    books: Optional[tuple[tuple[str, int]]] = None,
+    books: Optional[tuple[BookConfig]] = None,
 ):
-    books = books or ()  # type: ignore
+    books = books or cast(tuple[BookConfig], ())
     exchange = cryptocom()
     exchange.load_markets()
     optimal_thread_count = multiprocessing.cpu_count()
@@ -114,7 +122,7 @@ def cryptodotcom_sockets(
     )
     get_user_open_orders = get_user_open_orders_factory(response_messages, socket_bs)
     open_orders = guaranteed_socket.pipe(
-        subscribe_open_orders(private_messages, exchange), share()
+        subscribe_open_orders(private_messages), share()
     )
     open_orders_reloaded = open_orders.pipe(flat_map(lambda _: get_user_open_orders()))
 
