@@ -1,4 +1,4 @@
-from .order import OrderType, OrderStatus, OrderSide, Order
+from .order import OrderType, OrderStatus, OrderSide, Order, OrderDict
 from .response_message import CryptodotcomResponseMessage
 from .request import CryptodotcomRequestMessage
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
@@ -10,6 +10,7 @@ __all__ = [
     "OrderSide",
     "OrderStatus",
     "OrderType",
+    "OrderDict",
     "CryptodotcomResponseMessage",
     "CryptodotcomRequestMessage",
     "EnhancedWebsocket",
